package locales

// AUTOGENERATED FILE: DO NOT MODIFY BY HAND.
// Instead, modify the .po files in
// https://github.com/hebcal/hebcal-locales.git
// and run
//
//	npm run po2golang
//
// there. Then copy the contents of the go/ folder.

var dict_he_x_NoNikud = map[string]string{
	"Chukat":           "חוקת",
	"Erev Yom Kippur":  "ערב יום כיפור",
	"Korach":           "קורח",
	"Yom Kippur":       "יום כיפור",
	"Yom Kippur Katan": "יום כיפור קטן",
}

func Lookup_he_x_NoNikud(s string) (string, bool) {
	v, ok := dict_he_x_NoNikud[s]
	if ok {
		return v, true
	}
	return s, false
}
