/*
Package hebcal provides functionality for calculating Jewish holidays,
candle-lighting and havdalah times, and fast start/end times.

Hebcal incorporates and uses several related packages:

  - hdate: converts between Hebrew and Gregorian dates.
    Also includes functions for calculating personal anniversaries
    (Yahrzeit, Birthday) according to the Hebrew calendar.
  - dafyomi: Daf Yomi, a daily regimen of learning the Talmud.
  - greg: converts between Gregorian dates and R.D. (Rata Die)
    day numbers.
  - sedra: weekly Torah reading (Parashat HaShavua).
  - zmanim: calculates halachic times.
  - locales: translations and transliterations of Jewish holiday
    names into several languages.
*/
package hebcal
