package locales

// AUTOGENERATED FILE: DO NOT MODIFY BY HAND.
// Instead, modify the .po files in
// https://github.com/hebcal/hebcal-locales.git
// and run
//
//	npm run po2golang
//
// there. Then copy the contents of the go/ folder.

var dict_ashkenazi_standard = map[string]string{
	"Achrei Mot":                "Acharei",
	"Adar":                      "Ador",
	"Adar I":                    "Ador I",
	"Adar II":                   "Ador II",
	"Alot HaShachar":            "Alos HaShachar",
	"Arachin":                   "Arochin",
	"Asara B'Tevet":             "Asoro B'Teiveis",
	"Asara B'Tevet (Mincha)":    "Asoro B'Teiveis (Mincho)",
	"Av":                        "Ov",
	"Avodah Zarah":              "Avodo Zoro",
	"Avot":                      "Ovos",
	"Baba Batra":                "Bovo Basro",
	"Baba Kamma":                "Bovo Kammo",
	"Baba Metzia":               "Bovo Metzi'o",
	"Balak":                     "Bolok",
	"Bamidbar":                  "B'midbar",
	"Bechorot":                  "B'choros",
	"Bechukotai":                "B'chukosai",
	"Beha'alotcha":              "B'ha'aloscho",
	"Behar":                     "B'har",
	"Beitzah":                   "Beitzo",
	"Bekhorot":                  "B'choros",
	"Berachot":                  "B'rachos",
	"Bereshit":                  "B'reishis",
	"Beshalach":                 "B'shalach",
	"Chagigah":                  "Chogigo",
	"Chanukah":                  "Chanuko",
	"Chanukah: 1 Candle":        "Chanuko: 1 Candle",
	"Chanukah: 2 Candles":       "Chanuko: 2 Candles",
	"Chanukah: 3 Candles":       "Chanuko: 3 Candles",
	"Chanukah: 4 Candles":       "Chanuko: 4 Candles",
	"Chanukah: 5 Candles":       "Chanuko: 5 Candles",
	"Chanukah: 6 Candles":       "Chanuko: 6 Candles",
	"Chanukah: 7 Candles":       "Chanuko: 7 Candles",
	"Chanukah: 8 Candles":       "Chanuko: 8 Candles",
	"Chanukah: 8th Day":         "Chanuko: 8th Day",
	"Chayei Sara":               "Chayei Soro",
	"Cheshvan":                  "Cheshvon",
	"Chukat":                    "Chukas",
	"Devarim":                   "D'vorim",
	"Erev Rosh Hashana":         "Erev Rosh Hashono",
	"Erev Shavuot":              "Erev Shovu'os",
	"Erev Simchat Torah":        "Erev Simchas Toro",
	"Erev Sukkot":               "Erev Sukkos",
	"Erev Tish'a B'Av":          "Erev Tisho B'Ov",
	"Eruvin":                    "Eiruvin",
	"Havdalah":                  "Havdolo",
	"Horayot":                   "Horoyos",
	"Iyyar":                     "Iyyor",
	"Kedoshim":                  "K'doshim",
	"Keritot":                   "K'risos",
	"Ketubot":                   "K'subos",
	"Ki Tavo":                   "Ki Sovo",
	"Ki Teitzei":                "Ki Seitzei",
	"Ki Tisa":                   "Ki Siso",
	"Kislev":                    "Kisleiv",
	"Lag BaOmer":                "Lag BoOmer",
	"Lech-Lecha":                "Lech L'cho",
	"Leil Selichot":             "Slichos",
	"Makkot":                    "Makkos",
	"Matot":                     "Matos",
	"Megillah":                  "M'gillo",
	"Meilah":                    "M'ilo",
	"Menachot":                  "M'nochos",
	"Metzora":                   "M'tzoro",
	"Midot":                     "Midos",
	"Miketz":                    "Mikeitz",
	"Mishpatim":                 "Mishpotim",
	"Moed Katan":                "Mo'ed Koton",
	"Nasso":                     "Nosso",
	"Nazir":                     "Nozir",
	"Nedarim":                   "N'dorim",
	"Niddah":                    "Niddo",
	"Nisan":                     "Nison",
	"Nitzavim":                  "Nitzovim",
	"Parashat":                  "Porshas",
	"Pekudei":                   "P'kudei",
	"Pesach Sheni":              "Pesach Sheini",
	"Pesachim":                  "P'sochim",
	"Pinchas":                   "Pinchos",
	"Purim Katan":               "Purim Koton",
	"Re'eh":                     "R'ei",
	"Rosh Hashana":              "Rosh Hashono",
	"Rosh Hashana I":            "Rosh Hashono I",
	"Rosh Hashana II":           "Rosh Hashono II",
	"Sh'vat":                    "Sh'vot",
	"Shabbat":                   "Shabbos",
	"Shabbat Chazon":            "Shabbos Chazon",
	"Shabbat HaChodesh":         "Shabbos HaChodesh",
	"Shabbat HaGadol":           "Shabbos HaGodol",
	"Shabbat Machar Chodesh":    "Shabbos Mochor Chodesh",
	"Shabbat Nachamu":           "Shabbos Nachamu",
	"Shabbat Parah":             "Shabbos Poro",
	"Shabbat Rosh Chodesh":      "Shabbos Rosh Chodesh",
	"Shabbat Shekalim":          "Shabbos Shekolim",
	"Shabbat Shuva":             "Shabbos Shuvo",
	"Shabbat Zachor":            "Shabbos Zochor",
	"Shavuot":                   "Shovu'os",
	"Shavuot I":                 "Shovu'os I",
	"Shavuot II":                "Shovu'os II",
	"Shekalim":                  "Sh'kolim",
	"Shemot":                    "Sh'mos",
	"Shevuot":                   "Sh'vu'os",
	"Shmini":                    "Sh'mini",
	"Shmini Atzeret":            "Sh'mini Atzeres",
	"Shushan Purim":             "Shushon Purim",
	"Simchat Torah":             "Simchas Toro",
	"Sivan":                     "Sivon",
	"Sotah":                     "Soto",
	"Sukkah":                    "Sukko",
	"Sukkot":                    "Sukkos",
	"Sukkot I":                  "Sukkos I",
	"Sukkot II":                 "Sukkos II",
	"Sukkot II (CH''M)":         "Sukkos II (CH''M)",
	"Sukkot III (CH''M)":        "Sukkos III (CH''M)",
	"Sukkot IV (CH''M)":         "Sukkos IV (CH''M)",
	"Sukkot V (CH''M)":          "Sukkos V (CH''M)",
	"Sukkot VI (CH''M)":         "Sukkos VI (CH''M)",
	"Sukkot VII (Hoshana Raba)": "Sukkos VII (Hosha'ano Rabo)",
	"Ta'anit Bechorot":          "Ta'anis Bechoros",
	"Ta'anit Esther":            "Ta'anis Esteir",
	"Taanit":                    "Ta'anis",
	"Tamid":                     "Tomid",
	"Tamuz":                     "Tammuz",
	"Temurah":                   "T'muro",
	"Terumah":                   "T'rumo",
	"Tetzaveh":                  "T'tzave",
	"Tevet":                     "Teiveis",
	"Tish'a B'Av":               "Tisho B'Ov",
	"Tish'a B'Av (observed)":    "Tisho B'Ov (observed)",
	"Toldot":                    "Toldos",
	"Tu B'Av":                   "Tu B'Ov",
	"Tu B'Shvat":                "Tu BiSh'vot",
	"Tu BiShvat":                "Tu BiSh'vot",
	"Tzom Gedaliah":             "Tzom G'dalyo",
	"Tzom Tammuz":               "Shivo Osor B'Sammuz",
	"Vaera":                     "Vo'eiro",
	"Vaetchanan":                "Vo'eschanan",
	"Vayakhel":                  "Vayakheil",
	"Vayechi":                   "Vaichi",
	"Vayera":                    "Vayeiro",
	"Vayeshev":                  "Vayeishev",
	"Vayetzei":                  "Vayeitzei",
	"Vayikra":                   "Vayikro",
	"Vezot Haberakhah":          "V'zos Habrocho",
	"Yevamot":                   "Y'vomos",
	"Yitro":                     "Yisro",
	"Yom HaAliyah":              "Yom HaAliya",
	"Yom HaShoah":               "Yom HaSho'a",
	"Yom Kippur Katan":          "Yom Kippur Koton",
	"Yom Yerushalayim":          "Yom Y'rushalayim",
	"Yoma":                      "Yumo",
	"Zevachim":                  "Z'vochim",
}

func Lookup_ashkenazi_standard(s string) (string, bool) {
	v, ok := dict_ashkenazi_standard[s]
	if ok {
		return v, true
	}
	return s, false
}
